==> kubernetes-model-1.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/TagEventFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class TagEventFluent<T extends TagEventFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String created;     String dockerImageReference;     String image;     Map<String, Object> additionalProperties = new HashMap();

    public String getCreated(){
    return this.created;
    }
    public T withCreated( String created){
    this.created=created; return (T) this;
    }
    public String getDockerImageReference(){
    return this.dockerImageReference;
    }
    public T withDockerImageReference( String dockerImageReference){
    this.dockerImageReference=dockerImageReference; return (T) this;
    }
    public String getImage(){
    return this.image;
    }
    public T withImage( String image){
    this.image=image; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}

==> kubernetes-model-1.0.23-sources.jar: annotations/io/fabric8/openshift/api/model/TagEventFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class TagEventFluent<T extends TagEventFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String created;     String dockerImageReference;     String image;     Map<String, Object> additionalProperties = new HashMap();

    public String getCreated(){
    return this.created;
    }
    public T withCreated( String created){
    this.created=created; return (T) this;
    }
    public String getDockerImageReference(){
    return this.dockerImageReference;
    }
    public T withDockerImageReference( String dockerImageReference){
    this.dockerImageReference=dockerImageReference; return (T) this;
    }
    public String getImage(){
    return this.image;
    }
    public T withImage( String image){
    this.image=image; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
TagEventFluent that = (TagEventFluent) o;
if (created != null ? !created.equals(that.created) :that.created != null) return false;
if (dockerImageReference != null ? !dockerImageReference.equals(that.dockerImageReference) :that.dockerImageReference != null) return false;
if (image != null ? !image.equals(that.image) :that.image != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
